import Parser from '../class/abstract.js';
import { determineAction, } from '../function/action.js';
function parseAsMutableArray(b) {
    return !Array.isArray(b.array)
        ? determineAction(b)
        : b.array.map(b.parseElement);
}
function parseAsReadonlyArray(b) {
    return !Array.isArray(b.array)
        ? determineAction(b)
        : Object.freeze(b.array.map(b.parseElement));
}
class ArrayParser extends Parser {
    parseElement;
    constructor(value, parseElement) {
        super(value);
        this.parseElement = parseElement;
    }
}
class ReadonlyArrayParser extends ArrayParser {
    constructor(array, parseElement) {
        super(array, parseElement);
    }
    elseGet = (alternativeValue) => parseAsReadonlyArray({
        alternativeValue,
        array: this.value,
        ifParsingFailThen: 'get',
        parseElement: this.parseElement,
    });
    elseLazyGet = (alternativeValue) => parseAsReadonlyArray({
        alternativeValue,
        array: this.value,
        ifParsingFailThen: 'lazy-get',
        parseElement: this.parseElement,
    });
    elseThrow = (message) => parseAsReadonlyArray({
        message,
        array: this.value,
        ifParsingFailThen: 'throw',
        parseElement: this.parseElement,
    });
}
class MutableArrayParser extends ArrayParser {
    constructor(array, parseElement) {
        super(array, parseElement);
    }
    elseGet = (alternativeValue) => parseAsMutableArray({
        alternativeValue,
        array: this.value,
        ifParsingFailThen: 'get',
        parseElement: this.parseElement,
    });
    elseLazyGet = (alternativeValue) => parseAsMutableArray({
        alternativeValue,
        array: this.value,
        ifParsingFailThen: 'lazy-get',
        parseElement: this.parseElement,
    });
    elseThrow = (message) => parseAsMutableArray({
        message,
        array: this.value,
        ifParsingFailThen: 'throw',
        parseElement: this.parseElement,
    });
}
export { MutableArrayParser, parseAsMutableArray, ReadonlyArrayParser, parseAsReadonlyArray, };
//# sourceMappingURL=array.js.map