import Parser from '../class/abstract.js';
import { determineAction, } from '../function/action.js';
const isObject = (o) => o !== null && typeof o === 'object';
function parseAsMutableObject(b) {
    if (isObject(b.object)) {
        return b.parse(b.object);
    }
    return determineAction(b);
}
function parseAsReadonlyObject(b) {
    if (isObject(b.object)) {
        return Object.freeze(b.parse(b.object));
    }
    return determineAction(b);
}
class ObjectParser extends Parser {
    parse;
    constructor(value, parse) {
        super(value);
        this.parse = parse;
    }
}
class MutableObjectParser extends ObjectParser {
    constructor(object, parse) {
        super(object, parse);
    }
    elseGet = (alternativeValue) => parseAsMutableObject({
        alternativeValue,
        parse: this.parse,
        object: this.value,
        ifParsingFailThen: 'get',
    });
    elseLazyGet = (alternativeValue) => parseAsMutableObject({
        alternativeValue,
        parse: this.parse,
        object: this.value,
        ifParsingFailThen: 'lazy-get',
    });
    elseThrow = (message) => parseAsMutableObject({
        message,
        parse: this.parse,
        object: this.value,
        ifParsingFailThen: 'throw',
    });
}
class ReadonlyObjectParser extends ObjectParser {
    constructor(object, parse) {
        super(object, parse);
    }
    elseGet = (alternativeValue) => parseAsReadonlyObject({
        alternativeValue,
        parse: this.parse,
        object: this.value,
        ifParsingFailThen: 'get',
    });
    elseLazyGet = (alternativeValue) => parseAsReadonlyObject({
        alternativeValue,
        parse: this.parse,
        object: this.value,
        ifParsingFailThen: 'lazy-get',
    });
    elseThrow = (message) => parseAsReadonlyObject({
        message,
        parse: this.parse,
        object: this.value,
        ifParsingFailThen: 'throw',
    });
}
export { MutableObjectParser, parseAsMutableObject, ReadonlyObjectParser, parseAsReadonlyObject, };
//# sourceMappingURL=object.js.map